@@ -133,7 +133,7 @@ bubbleplot <- function(tab, joint = TRUE, magnify=1,
 
   if(! is.table(tab)){
    warning("L'input non e' una tabella")
-   return
+   return(NULL)
   }
     
   if(joint)
